@@ -40,8 +40,6 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "config.h"
 #endif
 
-#include <errno.h>
-
 #include "xf86.h"
 #include "i830.h"
 #include "i810_reg.h"
@@ -53,29 +51,15 @@ unsigned long intel_get_pixmap_pitch(PixmapPtr pixmap)
 	return (unsigned long)pixmap->devKind;
 }
 
-void I830Sync(ScrnInfoPtr scrn)
-{
-	intel_screen_private *intel = intel_get_screen_private(scrn);
-
-	if (I810_DEBUG & (DEBUG_VERBOSE_ACCEL | DEBUG_VERBOSE_SYNC))
-		ErrorF("I830Sync\n");
-
-	if (!scrn->vtSema || !intel->batch_bo)
-		return;
-
-	intel_batch_flush(scrn, TRUE);
-	intel_batch_wait_last(scrn);
-}
-
 void i830_debug_flush(ScrnInfoPtr scrn)
 {
 	intel_screen_private *intel = intel_get_screen_private(scrn);
 
 	if (intel->debug_flush & DEBUG_FLUSH_CACHES)
-		intel_batch_pipelined_flush(scrn);
+		intel_batch_emit_flush(scrn);
 
 	if (intel->debug_flush & DEBUG_FLUSH_BATCHES)
-		intel_batch_flush(scrn, FALSE);
+		intel_batch_submit(scrn);
 }
 
 /* The following function sets up the supported acceleration. Call it
